HMpTy 
=========================

*A python package and command-line tools for working with Hierarchical Triangular Meshes (HTMs). Generate HTM-ids, crossmatch sets of sky-coordinates and more*.

.. image:: http://i.imgur.com/5GG4979.png
    :width: 600 px

Here's a summary of what's included in the python package:

.. include:: /classes_and_functions.rst

Command-Line Usage
======

.. code-block:: bash 
   
    
    Documentation for HMpTy can be found here: http://HMpTy.readthedocs.org/en/stable
    
    
    Usage:
        hmpty index <tableName> <primaryIdCol> <raCol> <decCol> (-s <pathToSettingsFile>|--host <host> --user <user> --passwd <passwd> --dbName <dbName>)
        hmpty search <tableName> <raCol> <decCol> <ra> <dec> <radius> (-s <pathToSettingsFile>|--host <host> --user <user> --passwd <passwd> --dbName <dbName>) [(-r <format>|-r mysql <resultsTable>)]
    
    Options:
        index                 add HTMids to database table
        search                perform a conesearch on a database table
    
        tableName                                                       name of the table to add the HTMids to
        primaryIdCol                                                    the name of the unique primary ID column of the database table
        raCol                                                           name of the table column containing the right ascension
        decCol                                                          name of the table column containing the declination
        ra                                                              the right ascension of the centre of the conesearch circle
        dec                                                             the declination of the centre of the conesearch circle
        radius                                                          the radius of the conesearch circle (arcsec)
        -h, --help                                                      show this help message
        -v, --version                                                   show version
        -s <pathToSettingsFile>, --settings <pathToSettingsFile>        path to a settings file containing the database credentials
        --host <host>                                                   database host address
        --user <user>                                                   database username
        --passwd <passwd>                                               database password 
        --dbName <dbName>                                               database name
        -r <format>, --render <format>                                  select a format to render your results in
    
    

Installation
============

The easiest way to install HMpTy us to use ``pip``:

.. code:: bash

    pip install HMpTy

Or you can clone the `github repo <https://github.com/thespacedoctor/HMpTy>`__ and install from a local version of the code:

.. code:: bash

    git clone git@github.com:thespacedoctor/HMpTy.git
    cd HMpTy
    python setup.py install

To upgrade to the latest version of HMpTy use the command:

.. code:: bash

    pip install HMpTy --upgrade


Documentation
=============

Documentation for HMpTy is hosted by `Read the Docs <http://HMpTy.readthedocs.org/en/stable/>`__ (last `stable version <http://HMpTy.readthedocs.org/en/stable/>`__ and `latest version <http://HMpTy.readthedocs.org/en/latest/>`__).

Command-Line Tutorial
=====================

Indexing Database Tables with HTMids
------------------------------------

HMpTy can be used from the command-line to add Hierarchical Triangular Mesh (HTM) IDs to any database table that has populated equatorial coordinate columns.

To generate and populate the ``htm10ID``, ``htm13ID`` and ``htm16ID`` columns on a table run either:

.. code-block:: bash 
     
    hmpty index transientBucket primaryKeyId raDeg decDeg -s /path/to/my-settings.yaml

where the settings file contains the database credientials:

.. code-block:: yaml 
    
    database settings:
        db: mydatabase
        host: localhost
        user: myusername
        password: mypass

Or alternatively you can pass the credientials in directory via the command-line (less secure obviously):

.. code-block:: bash 

    hmpty index transientBucket primaryKeyId raDeg decDeg --host localhost --user myusername --passwd mypass --dbName mydatabase
 
Conesearching Database Tables
-----------------------------

It's possible to perform a conesearch on a database table (with existing HTMId columns pre-populated) from the command-line.

The syntax for the cl-conesearch is:

.. code-block:: bash 

    hmpty search <tableName> <raCol> <decCol> <ra> <dec> <radius> (-s <pathToSettingsFile>|--host <host> --user <user> --passwd <passwd> --dbName <dbName>)

So to perform a 10 arcsec conesearch on a *transientBucket* table with ra and dec columns named *raDeg* and *decDeg* respectively around the coordinates "21:19:41.31", "+21:57:56.3":

.. code-block:: bash 

    hmpty search transientBucket raDeg decDeg 21:19:41.31 +21:57:56.3 10. -s /path/to/my-settings.yaml

.. code-block:: text

     
    | decDegErr  | hostRedshiftType  | decDeg   | masterIDFlag  | telescope  | lastNonDetectionDate  | sherlockClassification  | discoveryPhase  | dateLastModified  | cy       | cx      | dateLastRead  | transientTypePredicationSource  | dateDeleted  | tripletImageUrl                                                  | transientTypePrediction  | surveyObjectUrl                                                      | htm10ID   | targetImageUrl                                                                                                                           | primaryKeyId  | raDeg     | instrument  | hostRedshift  | filter  | finderImageUrl  | htm13ID    | subtractedImageUrl  | transientRedshift  | raDegErr  | dateCreated  | cmSepArcsec  | observationDate  | classificationPhase  | observationMJD  | transientBucketId  | name        | transientRedshiftNotes  | classificationWRTMax  | tmpFlag  | cz      | referenceImageUrl                                                                                                                     | reducer  | htm16ID      | lastNonDetectionMJD  | magnitude  | survey          | magnitudeError  | limitingMag  | replacedByRowId  | htm20ID         | spectralType  | lightcurveURL  |
     
    |            |                   | 21.9656  | 1             |            | 2016-09-25            | SN                      |                 | 2016-09-30        | -0.5971  | 0.7096  |               |                                 |              |                                                                  |                          | http://wis-tns.weizmann.ac.il/object/2016grk                         | 13458566  |                                                                                                                                          | 1387901       | 319.9221  |             |               | Clear-  |                 | 861348238  |                     |                    |           | 2016-09-30   | 0.0043       | 2016-09-30       |                      | 57661.2291      | 1387901            | AT2016grk   |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287254  |                      | 18.7000    | POSS            |                 | 0            | 0                | 14112329537188  |               |                |
    |            |                   | 21.9656  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              | https://c4.staticflickr.com/6/5313/29951445811_cf5c76e8aa_o.jpg  | SN                       | http://www.rochesterastronomy.org/supernova.html#2016grk             | 13458566  |                                                                                                                                          | 1392947       | 319.9221  |             |               |         |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.0043       | 2016-09-30       |                      | 57661.2290      | 1387901            | AT2016grk   |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287254  |                      | 18.7000    | bright sn list  |                 | 0            | 0                | 14112329537188  |               |                |
    |            |                   | 21.9658  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              |                                                                  |                          | http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/  | 13458566  |                                                                                                                                          | 1398488       | 319.9220  |             |               | c       |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.5654       | 2016-09-30       |                      | 57661.3788      | 1387901            | ATLAS16dbz  |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287254  |                      | 17.7500    | ATLAS           | 0.0700          | 0            | 0                | 14112329537190  |               |                |
    |            |                   | 21.9657  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              |                                                                  |                          | http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/  | 13458566  |                                                                                                                                          | 1398490       | 319.9220  |             |               | c       |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.6391       | 2016-09-30       |                      | 57661.4019      | 1387901            | ATLAS16dbz  |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287255  |                      | 17.9400    | ATLAS           | 0.0800          | 0            | 0                | 14112329537309  |               |                |
    |            |                   | 21.9658  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              |                                                                  | orphan                   |                                                                      | 13458566  | http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_target.jpeg  | 1398485       | 319.9220  |             |               | c       |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.6537       | 2016-09-30       |                      | 57661.3495      | 1387901            | ATLAS16dbz  |                         |                       |          | 0.3741  | http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_ref.jpeg  |          | 55126287255  |                      | 17.8800    | ATLAS           |                 | 0            | 0                | 14112329537309  |               |                |
    |            |                   | 21.9658  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              |                                                                  |                          | http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/  | 13458566  |                                                                                                                                          | 1398489       | 319.9220  |             |               | c       |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.6893       | 2016-09-30       |                      | 57661.3588      | 1387901            | ATLAS16dbz  |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287254  |                      | 17.8000    | ATLAS           | 0.0700          | 0            | 0                | 14112329537198  |               |                |
    |            |                   | 21.9658  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              |                                                                  |                          | http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/  | 13458566  |                                                                                                                                          | 1398486       | 319.9220  |             |               | c       |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.7532       | 2016-09-30       |                      | 57661.3679      | 1387901            | ATLAS16dbz  |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287254  |                      | 17.8600    | ATLAS           | 0.0700          | 0            | 0                | 14112329537185  |               |                |
    |            |                   | 21.9657  | 0             |            |                       |                         |                 | 2016-10-01        | -0.5971  | 0.7096  |               |                                 |              |                                                                  |                          | http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/  | 13458566  |                                                                                                                                          | 1398487       | 319.9219  |             |               | c       |                 | 861348238  |                     |                    |           | 2016-10-01   | 0.8138       | 2016-09-30       |                      | 57661.3494      | 1387901            | ATLAS16dbz  |                         |                       |          | 0.3741  |                                                                                                                                       |          | 55126287255  |                      | 17.8800    | ATLAS           | 0.0700          | 0            | 0                | 14112329537311  |               |                |
     


Note RA and DEC can be in either sexegesiaml or decimal degree formats.

Again, you can instead pass in the database credientials via the command-line instead of a settings file:

.. code-block:: bash 
    
    hmpty search transientBucket raDeg decDeg 319.92212 21.96564 10. --host localhost --user myusername --passwd mypass --dbName mydatabase 

Renders
~~~~~~~

To render the results of the conesearch as json, csv, yaml or markdown use the ``-r <format>`` flag. For example:

.. code-block:: bash 

    hmpty search transientBucket raDeg decDeg 21:19:41.31 +21:57:56.3 10. -s /path/to/my-settings.yaml -r json

.. code-block:: text 
    
    [
        {
            "classificationPhase": null,
            "classificationWRTMax": null,
            "cmSepArcsec": 0.0043467057710126393,
            "cx": 0.709625112642,
            "cy": -0.597091649225,
            "cz": 0.374050480461,
            "dateCreated": "20160930t192332",
            "dateDeleted": null,
            "dateLastModified": "20160930t192332",
            "dateLastRead": null,
            "decDeg": 21.9656388889,
            "decDegErr": null,
            "discoveryPhase": null,
            "filter": "Clear-",
            "finderImageUrl": null,
            "hostRedshift": null, 
            ....

It's possible to also render the results as MySQL insert statements, but the name of the table to insert the result into is also needed.

.. code-block:: bash 

    hmpty search transientBucket raDeg decDeg 21:19:41.31 +21:57:56.3 10. -s /path/to/my-settings.yaml -r mysql my_results

.. code-block:: text

    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.00434670577101" ,"0.709625112642" ,"-0.597091649225" ,"0.374050480461" ,"2016-09-30 19:23:32" ,null ,"2016-09-30 19:23:32" ,null ,"21.9656388889" ,null ,null ,"Clear-" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287254" ,"14112329537188" ,null ,"2016-09-25 05:16:07" ,null ,null ,"0" ,"18.7" ,null ,"1" ,"AT2016grk" ,"2016-09-30 05:29:57" ,"57661.2291319" ,"1387901" ,"319.922125" ,null ,null ,null ,"0" ,"SN" ,null ,null ,"POSS" ,"http://wis-tns.weizmann.ac.il/object/2016grk" ,null ,null ,null ,"1387901" ,null ,null ,null ,null ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.00434670577101", cx="0.709625112642", cy="-0.597091649225", cz="0.374050480461", dateCreated="2016-09-30 19:23:32", dateDeleted=null, dateLastModified="2016-09-30 19:23:32", dateLastRead=null, decDeg="21.9656388889", decDegErr=null, discoveryPhase=null, filter="Clear-", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287254", htm20ID="14112329537188", instrument=null, lastNonDetectionDate="2016-09-25 05:16:07", lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="18.7", magnitudeError=null, masterIDFlag="1", name="AT2016grk", observationDate="2016-09-30 05:29:57", observationMJD="57661.2291319", primaryKeyId="1387901", raDeg="319.922125", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification="SN", spectralType=null, subtractedImageUrl=null, survey="POSS", surveyObjectUrl="http://wis-tns.weizmann.ac.il/object/2016grk", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction=null, tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.00434670577101" AND  cx="0.709625112642" AND  cy="-0.597091649225" AND  cz="0.374050480461" AND  dateCreated="2016-09-30 19:23:32" AND  dateDeleted is null AND  dateLastModified="2016-09-30 19:23:32" AND  dateLastRead is null AND  decDeg="21.9656388889" AND  decDegErr is null AND  discoveryPhase is null AND  filter="Clear-" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537188" AND  instrument is null AND  lastNonDetectionDate="2016-09-25 05:16:07" AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="18.7" AND  magnitudeError is null AND  masterIDFlag="1" AND  name="AT2016grk" AND  observationDate="2016-09-30 05:29:57" AND  observationMJD="57661.2291319" AND  primaryKeyId="1387901" AND  raDeg="319.922125" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification="SN" AND  spectralType is null AND  subtractedImageUrl is null AND  survey="POSS" AND  surveyObjectUrl="http://wis-tns.weizmann.ac.il/object/2016grk" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.00434670577101" AND  cx="0.709625112642" AND  cy="-0.597091649225" AND  cz="0.374050480461" AND  dateCreated="2016-09-30 19:23:32" AND  dateDeleted is null AND  dateLastModified="2016-09-30 19:23:32" AND  dateLastRead is null AND  decDeg="21.9656388889" AND  decDegErr is null AND  discoveryPhase is null AND  filter="Clear-" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537188" AND  instrument is null AND  lastNonDetectionDate="2016-09-25 05:16:07" AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="18.7" AND  magnitudeError is null AND  masterIDFlag="1" AND  name="AT2016grk" AND  observationDate="2016-09-30 05:29:57" AND  observationMJD="57661.2291319" AND  primaryKeyId="1387901" AND  raDeg="319.922125" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification="SN" AND  spectralType is null AND  subtractedImageUrl is null AND  survey="POSS" AND  surveyObjectUrl="http://wis-tns.weizmann.ac.il/object/2016grk" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.00434670577101" ,"0.709625112642" ,"-0.597091649225" ,"0.374050480461" ,"2016-10-01 06:25:16" ,null ,"2016-10-01 06:25:16" ,null ,"21.9656388889" ,null ,null ,null ,null ,null ,null ,"13458566" ,"861348238" ,"55126287254" ,"14112329537188" ,null ,null ,null ,null ,"0" ,"18.7" ,null ,"0" ,"AT2016grk" ,"2016-09-30 05:29:45" ,"57661.2289931" ,"1392947" ,"319.922125" ,null ,null ,null ,"0" ,null ,null ,null ,"bright sn list" ,"http://www.rochesterastronomy.org/supernova.html#2016grk" ,null ,null ,null ,"1387901" ,null ,null ,null ,"SN" ,"https://c4.staticflickr.com/6/5313/29951445811_cf5c76e8aa_o.jpg")  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.00434670577101", cx="0.709625112642", cy="-0.597091649225", cz="0.374050480461", dateCreated="2016-10-01 06:25:16", dateDeleted=null, dateLastModified="2016-10-01 06:25:16", dateLastRead=null, decDeg="21.9656388889", decDegErr=null, discoveryPhase=null, filter=null, finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287254", htm20ID="14112329537188", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="18.7", magnitudeError=null, masterIDFlag="0", name="AT2016grk", observationDate="2016-09-30 05:29:45", observationMJD="57661.2289931", primaryKeyId="1392947", raDeg="319.922125", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="bright sn list", surveyObjectUrl="http://www.rochesterastronomy.org/supernova.html#2016grk", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction="SN", tripletImageUrl="https://c4.staticflickr.com/6/5313/29951445811_cf5c76e8aa_o.jpg", updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.00434670577101" AND  cx="0.709625112642" AND  cy="-0.597091649225" AND  cz="0.374050480461" AND  dateCreated="2016-10-01 06:25:16" AND  dateDeleted is null AND  dateLastModified="2016-10-01 06:25:16" AND  dateLastRead is null AND  decDeg="21.9656388889" AND  decDegErr is null AND  discoveryPhase is null AND  filter is null AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537188" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="18.7" AND  magnitudeError is null AND  masterIDFlag="0" AND  name="AT2016grk" AND  observationDate="2016-09-30 05:29:45" AND  observationMJD="57661.2289931" AND  primaryKeyId="1392947" AND  raDeg="319.922125" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="bright sn list" AND  surveyObjectUrl="http://www.rochesterastronomy.org/supernova.html#2016grk" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction="SN" AND  tripletImageUrl="https://c4.staticflickr.com/6/5313/29951445811_cf5c76e8aa_o.jpg", 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.00434670577101" AND  cx="0.709625112642" AND  cy="-0.597091649225" AND  cz="0.374050480461" AND  dateCreated="2016-10-01 06:25:16" AND  dateDeleted is null AND  dateLastModified="2016-10-01 06:25:16" AND  dateLastRead is null AND  decDeg="21.9656388889" AND  decDegErr is null AND  discoveryPhase is null AND  filter is null AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537188" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="18.7" AND  magnitudeError is null AND  masterIDFlag="0" AND  name="AT2016grk" AND  observationDate="2016-09-30 05:29:45" AND  observationMJD="57661.2289931" AND  primaryKeyId="1392947" AND  raDeg="319.922125" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="bright sn list" AND  surveyObjectUrl="http://www.rochesterastronomy.org/supernova.html#2016grk" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction="SN" AND  tripletImageUrl="https://c4.staticflickr.com/6/5313/29951445811_cf5c76e8aa_o.jpg", dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.56535588648" ,"0.70962346768" ,"-0.597092274742" ,"0.374052602667" ,"2016-10-01 19:12:26" ,null ,"2016-10-01 19:12:26" ,null ,"21.96577" ,null ,null ,"c" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287254" ,"14112329537190" ,null ,null ,null ,null ,"0" ,"17.75" ,"0.07" ,"0" ,"ATLAS16dbz" ,"2016-09-30 09:05:29" ,"57661.3788134" ,"1398488" ,"319.92203" ,null ,null ,null ,"0" ,null ,null ,null ,"ATLAS" ,"http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" ,null ,null ,null ,"1387901" ,null ,null ,null ,null ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.56535588648", cx="0.70962346768", cy="-0.597092274742", cz="0.374052602667", dateCreated="2016-10-01 19:12:26", dateDeleted=null, dateLastModified="2016-10-01 19:12:26", dateLastRead=null, decDeg="21.96577", decDegErr=null, discoveryPhase=null, filter="c", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287254", htm20ID="14112329537190", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="17.75", magnitudeError="0.07", masterIDFlag="0", name="ATLAS16dbz", observationDate="2016-09-30 09:05:29", observationMJD="57661.3788134", primaryKeyId="1398488", raDeg="319.92203", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="ATLAS", surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction=null, tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.56535588648" AND  cx="0.70962346768" AND  cy="-0.597092274742" AND  cz="0.374052602667" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96577" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537190" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.75" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 09:05:29" AND  observationMJD="57661.3788134" AND  primaryKeyId="1398488" AND  raDeg="319.92203" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.56535588648" AND  cx="0.70962346768" AND  cy="-0.597092274742" AND  cz="0.374052602667" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96577" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537190" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.75" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 09:05:29" AND  observationMJD="57661.3788134" AND  primaryKeyId="1398488" AND  raDeg="319.92203" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.639098796909" ,"0.709622938008" ,"-0.597093309838" ,"0.374051955215" ,"2016-10-01 19:12:26" ,null ,"2016-10-01 19:12:26" ,null ,"21.96573" ,null ,null ,"c" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287255" ,"14112329537309" ,null ,null ,null ,null ,"0" ,"17.94" ,"0.08" ,"0" ,"ATLAS16dbz" ,"2016-09-30 09:38:41" ,"57661.4018678" ,"1398490" ,"319.92196" ,null ,null ,null ,"0" ,null ,null ,null ,"ATLAS" ,"http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" ,null ,null ,null ,"1387901" ,null ,null ,null ,null ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.639098796909", cx="0.709622938008", cy="-0.597093309838", cz="0.374051955215", dateCreated="2016-10-01 19:12:26", dateDeleted=null, dateLastModified="2016-10-01 19:12:26", dateLastRead=null, decDeg="21.96573", decDegErr=null, discoveryPhase=null, filter="c", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287255", htm20ID="14112329537309", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="17.94", magnitudeError="0.08", masterIDFlag="0", name="ATLAS16dbz", observationDate="2016-09-30 09:38:41", observationMJD="57661.4018678", primaryKeyId="1398490", raDeg="319.92196", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="ATLAS", surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction=null, tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.639098796909" AND  cx="0.709622938008" AND  cy="-0.597093309838" AND  cz="0.374051955215" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96573" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287255" AND  htm20ID="14112329537309" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.94" AND  magnitudeError="0.08" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 09:38:41" AND  observationMJD="57661.4018678" AND  primaryKeyId="1398490" AND  raDeg="319.92196" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.639098796909" AND  cx="0.709622938008" AND  cy="-0.597093309838" AND  cz="0.374051955215" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96573" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287255" AND  htm20ID="14112329537309" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.94" AND  magnitudeError="0.08" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 09:38:41" AND  observationMJD="57661.4018678" AND  primaryKeyId="1398490" AND  raDeg="319.92196" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.653735010571" ,"0.709623008285" ,"-0.597092861276" ,"0.374052537922" ,"2016-10-01 19:12:26" ,null ,"2016-10-01 19:12:26" ,null ,"21.965766" ,null ,null ,"c" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287255" ,"14112329537309" ,null ,null ,null ,null ,"0" ,"17.88" ,null ,"0" ,"ATLAS16dbz" ,"2016-09-30 08:23:12" ,"57661.34945" ,"1398485" ,"319.921984" ,null ,null ,"http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_ref.jpeg" ,"0" ,null ,null ,null ,"ATLAS" ,null ,"http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_target.jpeg" ,null ,null ,"1387901" ,null ,null ,null ,"orphan" ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.653735010571", cx="0.709623008285", cy="-0.597092861276", cz="0.374052537922", dateCreated="2016-10-01 19:12:26", dateDeleted=null, dateLastModified="2016-10-01 19:12:26", dateLastRead=null, decDeg="21.965766", decDegErr=null, discoveryPhase=null, filter="c", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287255", htm20ID="14112329537309", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="17.88", magnitudeError=null, masterIDFlag="0", name="ATLAS16dbz", observationDate="2016-09-30 08:23:12", observationMJD="57661.34945", primaryKeyId="1398485", raDeg="319.921984", raDegErr=null, reducer=null, referenceImageUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_ref.jpeg", replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="ATLAS", surveyObjectUrl=null, targetImageUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_target.jpeg", telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction="orphan", tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.653735010571" AND  cx="0.709623008285" AND  cy="-0.597092861276" AND  cz="0.374052537922" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.965766" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287255" AND  htm20ID="14112329537309" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.88" AND  magnitudeError is null AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:23:12" AND  observationMJD="57661.34945" AND  primaryKeyId="1398485" AND  raDeg="319.921984" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_ref.jpeg" AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl is null AND  targetImageUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_target.jpeg" AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction="orphan" AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.653735010571" AND  cx="0.709623008285" AND  cy="-0.597092861276" AND  cz="0.374052537922" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.965766" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287255" AND  htm20ID="14112329537309" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.88" AND  magnitudeError is null AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:23:12" AND  observationMJD="57661.34945" AND  primaryKeyId="1398485" AND  raDeg="319.921984" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_ref.jpeg" AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl is null AND  targetImageUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/site_media/images/data/atlas3//57661/1211941281215756900_57661.401_02a57661o0355c_8445_target.jpeg" AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction="orphan" AND  tripletImageUrl=null, dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.689312710877" ,"0.709623267865" ,"-0.597092106613" ,"0.37405325012" ,"2016-10-01 19:12:26" ,null ,"2016-10-01 19:12:26" ,null ,"21.96581" ,null ,null ,"c" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287254" ,"14112329537198" ,null ,null ,null ,null ,"0" ,"17.8" ,"0.07" ,"0" ,"ATLAS16dbz" ,"2016-09-30 08:36:38" ,"57661.3587675" ,"1398489" ,"319.92203" ,null ,null ,null ,"0" ,null ,null ,null ,"ATLAS" ,"http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" ,null ,null ,null ,"1387901" ,null ,null ,null ,null ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.689312710877", cx="0.709623267865", cy="-0.597092106613", cz="0.37405325012", dateCreated="2016-10-01 19:12:26", dateDeleted=null, dateLastModified="2016-10-01 19:12:26", dateLastRead=null, decDeg="21.96581", decDegErr=null, discoveryPhase=null, filter="c", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287254", htm20ID="14112329537198", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="17.8", magnitudeError="0.07", masterIDFlag="0", name="ATLAS16dbz", observationDate="2016-09-30 08:36:38", observationMJD="57661.3587675", primaryKeyId="1398489", raDeg="319.92203", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="ATLAS", surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction=null, tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.689312710877" AND  cx="0.709623267865" AND  cy="-0.597092106613" AND  cz="0.37405325012" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96581" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537198" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.8" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:36:38" AND  observationMJD="57661.3587675" AND  primaryKeyId="1398489" AND  raDeg="319.92203" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.689312710877" AND  cx="0.709623267865" AND  cy="-0.597092106613" AND  cz="0.37405325012" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96581" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537198" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.8" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:36:38" AND  observationMJD="57661.3587675" AND  primaryKeyId="1398489" AND  raDeg="319.92203" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.753210240087" ,"0.709623009487" ,"-0.597092312286" ,"0.374053411983" ,"2016-10-01 19:12:26" ,null ,"2016-10-01 19:12:26" ,null ,"21.96582" ,null ,null ,"c" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287254" ,"14112329537185" ,null ,null ,null ,null ,"0" ,"17.86" ,"0.07" ,"0" ,"ATLAS16dbz" ,"2016-09-30 08:49:45" ,"57661.3678845" ,"1398486" ,"319.92201" ,null ,null ,null ,"0" ,null ,null ,null ,"ATLAS" ,"http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" ,null ,null ,null ,"1387901" ,null ,null ,null ,null ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.753210240087", cx="0.709623009487", cy="-0.597092312286", cz="0.374053411983", dateCreated="2016-10-01 19:12:26", dateDeleted=null, dateLastModified="2016-10-01 19:12:26", dateLastRead=null, decDeg="21.96582", decDegErr=null, discoveryPhase=null, filter="c", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287254", htm20ID="14112329537185", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="17.86", magnitudeError="0.07", masterIDFlag="0", name="ATLAS16dbz", observationDate="2016-09-30 08:49:45", observationMJD="57661.3678845", primaryKeyId="1398486", raDeg="319.92201", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="ATLAS", surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction=null, tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.753210240087" AND  cx="0.709623009487" AND  cy="-0.597092312286" AND  cz="0.374053411983" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96582" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537185" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.86" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:49:45" AND  observationMJD="57661.3678845" AND  primaryKeyId="1398486" AND  raDeg="319.92201" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.753210240087" AND  cx="0.709623009487" AND  cy="-0.597092312286" AND  cz="0.374053411983" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.96582" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287254" AND  htm20ID="14112329537185" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.86" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:49:45" AND  observationMJD="57661.3678845" AND  primaryKeyId="1398486" AND  raDeg="319.92201" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, dateLastModified, NOW()) ;
    INSERT INTO `my_results` (classificationPhase,classificationWRTMax,cmSepArcsec,cx,cy,cz,dateCreated,dateDeleted,dateLastModified,dateLastRead,decDeg,decDegErr,discoveryPhase,filter,finderImageUrl,hostRedshift,hostRedshiftType,htm10ID,htm13ID,htm16ID,htm20ID,instrument,lastNonDetectionDate,lastNonDetectionMJD,lightcurveURL,limitingMag,magnitude,magnitudeError,masterIDFlag,name,observationDate,observationMJD,primaryKeyId,raDeg,raDegErr,reducer,referenceImageUrl,replacedByRowId,sherlockClassification,spectralType,subtractedImageUrl,survey,surveyObjectUrl,targetImageUrl,telescope,tmpFlag,transientBucketId,transientRedshift,transientRedshiftNotes,transientTypePredicationSource,transientTypePrediction,tripletImageUrl) VALUES (null ,null ,"0.813780637869" ,"0.70962235838" ,"-0.597094302902" ,"0.374051469625" ,"2016-10-01 19:12:26" ,null ,"2016-10-01 19:12:26" ,null ,"21.9657" ,null ,null ,"c" ,null ,null ,null ,"13458566" ,"861348238" ,"55126287255" ,"14112329537311" ,null ,null ,null ,null ,"0" ,"17.88" ,"0.07" ,"0" ,"ATLAS16dbz" ,"2016-09-30 08:23:12" ,"57661.3494495" ,"1398487" ,"319.92189" ,null ,null ,null ,"0" ,null ,null ,null ,"ATLAS" ,"http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" ,null ,null ,null ,"1387901" ,null ,null ,null ,null ,null)  ON DUPLICATE KEY UPDATE  classificationPhase=null, classificationWRTMax=null, cmSepArcsec="0.813780637869", cx="0.70962235838", cy="-0.597094302902", cz="0.374051469625", dateCreated="2016-10-01 19:12:26", dateDeleted=null, dateLastModified="2016-10-01 19:12:26", dateLastRead=null, decDeg="21.9657", decDegErr=null, discoveryPhase=null, filter="c", finderImageUrl=null, hostRedshift=null, hostRedshiftType=null, htm10ID="13458566", htm13ID="861348238", htm16ID="55126287255", htm20ID="14112329537311", instrument=null, lastNonDetectionDate=null, lastNonDetectionMJD=null, lightcurveURL=null, limitingMag="0", magnitude="17.88", magnitudeError="0.07", masterIDFlag="0", name="ATLAS16dbz", observationDate="2016-09-30 08:23:12", observationMJD="57661.3494495", primaryKeyId="1398487", raDeg="319.92189", raDegErr=null, reducer=null, referenceImageUrl=null, replacedByRowId="0", sherlockClassification=null, spectralType=null, subtractedImageUrl=null, survey="ATLAS", surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/", targetImageUrl=null, telescope=null, tmpFlag=null, transientBucketId="1387901", transientRedshift=null, transientRedshiftNotes=null, transientTypePredicationSource=null, transientTypePrediction=null, tripletImageUrl=null, updated=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.813780637869" AND  cx="0.70962235838" AND  cy="-0.597094302902" AND  cz="0.374051469625" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.9657" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287255" AND  htm20ID="14112329537311" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.88" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:23:12" AND  observationMJD="57661.3494495" AND  primaryKeyId="1398487" AND  raDeg="319.92189" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, 0, 1), dateLastModified=IF( classificationPhase=null AND  classificationWRTMax is null AND  cmSepArcsec="0.813780637869" AND  cx="0.70962235838" AND  cy="-0.597094302902" AND  cz="0.374051469625" AND  dateCreated="2016-10-01 19:12:26" AND  dateDeleted is null AND  dateLastModified="2016-10-01 19:12:26" AND  dateLastRead is null AND  decDeg="21.9657" AND  decDegErr is null AND  discoveryPhase is null AND  filter="c" AND  finderImageUrl is null AND  hostRedshift is null AND  hostRedshiftType is null AND  htm10ID="13458566" AND  htm13ID="861348238" AND  htm16ID="55126287255" AND  htm20ID="14112329537311" AND  instrument is null AND  lastNonDetectionDate is null AND  lastNonDetectionMJD is null AND  lightcurveURL is null AND  limitingMag="0" AND  magnitude="17.88" AND  magnitudeError="0.07" AND  masterIDFlag="0" AND  name="ATLAS16dbz" AND  observationDate="2016-09-30 08:23:12" AND  observationMJD="57661.3494495" AND  primaryKeyId="1398487" AND  raDeg="319.92189" AND  raDegErr is null AND  reducer is null AND  referenceImageUrl is null AND  replacedByRowId="0" AND  sherlockClassification is null AND  spectralType is null AND  subtractedImageUrl is null AND  survey="ATLAS" AND  surveyObjectUrl="http://psweb.mp.qub.ac.uk/sne/atlas3/candidate/1211941281215756900/" AND  targetImageUrl is null AND  telescope is null AND  tmpFlag is null AND  transientBucketId="1387901" AND  transientRedshift is null AND  transientRedshiftNotes is null AND  transientTypePredicationSource is null AND  transientTypePrediction is null AND  tripletImageUrl=null, dateLastModified, NOW()) ;



    


